==> igniteui-react-charts-18.6.0.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicator extends StrategyBasedIndicator {
        bc() {
            return new PercentagePriceOscillatorIndicator();
        }
        get_y0() {
            return new PercentagePriceOscillatorIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return PercentagePriceOscillatorIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.zm));
        }
        set shortPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.zm, a);
        }
        y8() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.zl));
        }
        set longPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.zl, a);
        }
        y5() {
            return this.longPeriod;
        }
    }
    PercentagePriceOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentagePriceOscillatorIndicator.zm = /*@__PURE__*/ StrategyBasedIndicator.zk(10, PercentagePriceOscillatorIndicator.$);
    PercentagePriceOscillatorIndicator.zl = /*@__PURE__*/ StrategyBasedIndicator.zg(30, PercentagePriceOscillatorIndicator.$);
    return PercentagePriceOscillatorIndicator;
})();

==> igniteui-react-charts-18.7.2.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicator extends StrategyBasedIndicator {
        bi() {
            return new PercentagePriceOscillatorIndicator();
        }
        get_abn() {
            return new PercentagePriceOscillatorIndicatorStrategy();
        }
        get abn() {
            return this.get_abn();
        }
        get_ab0() {
            return PercentagePriceOscillatorIndicator.$;
        }
        get ab0() {
            return this.get_ab0();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.ab9));
        }
        set shortPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.ab9, a);
        }
        abv() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.ab8));
        }
        set longPeriod(a) {
            this.h(PercentagePriceOscillatorIndicator.ab8, a);
        }
        abs() {
            return this.longPeriod;
        }
    }
    PercentagePriceOscillatorIndicator.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentagePriceOscillatorIndicator.ab9 = /*@__PURE__*/ StrategyBasedIndicator.ab7(10, PercentagePriceOscillatorIndicator.$);
    PercentagePriceOscillatorIndicator.ab8 = /*@__PURE__*/ StrategyBasedIndicator.ab3(30, PercentagePriceOscillatorIndicator.$);
    return PercentagePriceOscillatorIndicator;
})();
